@@ -307,9 +307,7 @@ where
 ///
 /// Each `(exchange, msg_type, market_type, day)` will launch a process.
 fn process_files_of_day(
-    exchange: &str,
     msg_type: MessageType,
-    market_type: MarketType,
     day: &str,
     input_dir: &str,
     output_dir_raw: &str,
@@ -320,10 +318,7 @@ fn process_files_of_day(
 
     // split
     {
-        let glob_pattern = format!(
-            "{}/**/{}.{}.{}.{}-??-??.json.gz",
-            input_dir, exchange, market_type, msg_type, day
-        );
+        let glob_pattern = format!("{}/**/*.*.{}.{}-??-??.json.gz", input_dir, msg_type, day);
         let mut paths: Vec<PathBuf> = glob(&glob_pattern)
             .unwrap()
             .filter_map(Result::ok)
@@ -346,8 +341,8 @@ fn process_files_of_day(
             };
             let mut paths_of_next_day: Vec<PathBuf> = glob(
                 format!(
-                    "{}/**/{}.{}.{}.{}-??.json.gz",
-                    input_dir, exchange, market_type, msg_type, next_day_first_hour
+                    "{}/**/*.*.{}.{}-??.json.gz",
+                    input_dir, msg_type, next_day_first_hour
                 )
                 .as_str(),
             )
@@ -357,24 +352,21 @@ fn process_files_of_day(
             paths.append(&mut paths_of_next_day);
         }
 
-        info!(
-            "Started split {} {} {} {}",
-            exchange, market_type, msg_type, day
-        );
+        info!("Started split {} {}", msg_type, day);
         #[allow(clippy::type_complexity)]
         let (tx, rx): (Sender<(i64, i64)>, Receiver<(i64, i64)>) = mpsc::channel();
         let start_timstamp = Instant::now();
         // small files get processed first
         paths.sort_by_cached_key(|path| std::fs::metadata(path).unwrap().len());
+        // key = exchange.market_type.msg_type
         let mut visited_map: HashMap<String, Arc<Mutex<HashSet<u64>>>> = HashMap::new();
         let mut split_files_map: HashMap<String, Arc<Mutex<HashMap<String, Output>>>> =
             HashMap::new();
         for path in paths {
             let file_name = path.as_path().file_name().unwrap();
             let v: Vec<&str> = file_name.to_str().unwrap().split('.').collect();
-            assert_eq!(exchange, v[0]);
+            let exchange = v[0];
             let market_type_str = v[1];
-            assert_eq!(market_type, MarketType::from_str(market_type_str).unwrap());
             let msg_type_str = v[2];
             assert_eq!(msg_type, MessageType::from_str(msg_type_str).unwrap());
             let output_dir_raw = Path::new(output_dir_raw)
@@ -430,9 +422,7 @@ fn process_files_of_day(
         if error_ratio > 0.01 {
             // error ratio > 1%
             error!(
-                "Failed to split {} {} {} {}, because error ratio {}/{}={}% is higher than 1% !",
-                exchange,
-                market_type,
+                "Failed to split {} {}, because error ratio {}/{}={}% is higher than 1% !",
                 msg_type,
                 day,
                 error_lines,
@@ -441,16 +431,13 @@ fn process_files_of_day(
             );
             return false;
         } else {
-            info!("Finished split {} {} {} {}, dropped {} malformed lines out of {} lines, time elapsed {} seconds", exchange, market_type, msg_type, day, error_lines, total_lines, start_timstamp.elapsed().as_secs());
+            info!("Finished split {} {}, dropped {} malformed lines out of {} lines, time elapsed {} seconds", msg_type, day, error_lines, total_lines, start_timstamp.elapsed().as_secs());
         }
     }
 
     // sort by timestamp
     {
-        let glob_pattern = format!(
-            "{}/**/{}.{}.{}.*.{}.json.gz",
-            output_dir_raw, exchange, market_type, msg_type, day
-        );
+        let glob_pattern = format!("{}/**/*.*.{}.*.{}.json.gz", output_dir_raw, msg_type, day);
         let paths_raw: Vec<PathBuf> = glob(&glob_pattern)
             .unwrap()
             .filter_map(Result::ok)
@@ -461,8 +448,8 @@ fn process_files_of_day(
         }
 
         let glob_pattern = format!(
-            "{}/**/{}.{}.{}.*.{}.json.gz",
-            output_dir_parsed, exchange, market_type, msg_type, day
+            "{}/**/*.*.{}.*.{}.json.gz",
+            output_dir_parsed, msg_type, day
         );
         let paths_parsed: Vec<PathBuf> = glob(&glob_pattern)
             .unwrap()
@@ -473,10 +460,7 @@ fn process_files_of_day(
             return false;
         }
 
-        info!(
-            "Started sort {} {} {} {}",
-            exchange, market_type, msg_type, day
-        );
+        info!("Started sort {} {}", msg_type, day);
         #[allow(clippy::type_complexity)]
         let (tx, rx): (Sender<(i64, i64)>, Receiver<(i64, i64)>) = mpsc::channel();
         let mut paths: Vec<PathBuf> = paths_raw
@@ -513,9 +497,7 @@ fn process_files_of_day(
         }
         if error_lines == 0 {
             info!(
-                "Finished sort {} {} {} {}, time elapsed {} seconds",
-                exchange,
-                market_type,
+                "Finished sort {} {}, time elapsed {} seconds",
                 msg_type,
                 day,
                 start_timstamp.elapsed().as_secs()
@@ -523,9 +505,7 @@ fn process_files_of_day(
             true
         } else {
             error!(
-                "Failed to sort {} {} {} {}, found {} malformed lines out of {} lines, time elapsed {} seconds",
-                exchange,
-                market_type,
+                "Failed to sort {} {}, found {} malformed lines out of {} lines, time elapsed {} seconds",
                 msg_type,
                 day,
                 error_lines, total_lines,
@@ -541,53 +521,36 @@ fn main() {
     assert!(setrlimit(Resource::NOFILE, 4096, 4096).is_ok());
 
     let args: Vec<String> = env::args().collect();
-    if args.len() != 8 {
-        eprintln!("Usage: crypto-daily-processor <exchange> <msg_type> <market_type> <day> <input_dir> <output_dir_raw> <output_dir_parsed>");
+    if args.len() != 6 {
+        eprintln!("Usage: crypto-daily-processor <msg_type> <day> <input_dir> <output_dir_raw> <output_dir_parsed>");
         std::process::exit(1);
     }
 
-    let exchange: &'static str = Box::leak(args[1].clone().into_boxed_str());
-
-    let msg_type = MessageType::from_str(&args[2]);
+    let msg_type = MessageType::from_str(&args[1]);
     if msg_type.is_err() {
-        eprintln!("Unknown msg type: {}", &args[2]);
+        eprintln!("Unknown msg type: {}", &args[1]);
         std::process::exit(1);
     }
     let msg_type = msg_type.unwrap();
 
-    let market_type = MarketType::from_str(&args[3]);
-    if market_type.is_err() {
-        eprintln!("Unknown market type: {}", &args[3]);
-        std::process::exit(1);
-    }
-    let market_type = market_type.unwrap();
-
-    let day: &'static str = Box::leak(args[4].clone().into_boxed_str());
+    let day: &'static str = Box::leak(args[2].clone().into_boxed_str());
     let re = Regex::new(r"^\d{4}-\d{2}-\d{2}$").unwrap();
     if !re.is_match(day) {
         eprintln!("{} is invalid, day should be yyyy-MM-dd", day);
         std::process::exit(1);
     }
 
-    let input_dir: &'static str = Box::leak(args[5].clone().into_boxed_str());
+    let input_dir: &'static str = Box::leak(args[3].clone().into_boxed_str());
     if !Path::new(input_dir).is_dir() {
         eprintln!("{} does NOT exist", input_dir);
         std::process::exit(1);
     }
-    let output_dir_raw: &'static str = Box::leak(args[6].clone().into_boxed_str());
-    let output_dir_parsed: &'static str = Box::leak(args[7].clone().into_boxed_str());
+    let output_dir_raw: &'static str = Box::leak(args[4].clone().into_boxed_str());
+    let output_dir_parsed: &'static str = Box::leak(args[5].clone().into_boxed_str());
     std::fs::create_dir_all(Path::new(output_dir_raw)).unwrap();
     std::fs::create_dir_all(Path::new(output_dir_parsed)).unwrap();
 
-    if !process_files_of_day(
-        exchange,
-        msg_type,
-        market_type,
-        day,
-        input_dir,
-        output_dir_raw,
-        output_dir_parsed,
-    ) {
+    if !process_files_of_day(msg_type, day, input_dir, output_dir_raw, output_dir_parsed) {
         std::process::exit(1);
     }
 }
